@@ -13,7 +13,7 @@ use std::{
 
 const EXCHANGE_NAME: &str = "bybit";
 
-#[test_case(MarketType::InverseFuture, "BTCUSDM21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
@@ -26,7 +26,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDM21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
@@ -39,7 +39,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDM21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
@@ -52,7 +52,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::InverseFuture, "BTCUSDM21")]
+#[test_case(MarketType::InverseFuture, "BTCUSDU21")]
 #[test_case(MarketType::InverseSwap, "BTCUSD")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
